[PATCH] smbd: fix mis-spellings of "hierarchy" in vfs.c

Michael Adam obnox at samba.org
Tue Sep 11 07:09:12 UTC 2018


See attached.

Review/push appreciated.

Thanks - Michael
-------------- next part --------------
From 22991b699d54f6f12f8e3ebce3327459dba06213 Mon Sep 17 00:00:00 2001
From: Michael Adam <obnox at samba.org>
Date: Mon, 20 Aug 2018 12:04:20 +0200
Subject: [PATCH] smbd:vfs: fix mis-spellings of hierarchy in comments

Signed-off-by: Michael Adam <obnox at samba.org>
---
 source3/smbd/vfs.c | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/source3/smbd/vfs.c b/source3/smbd/vfs.c
index a6c49cfad34..28ebfc92dc7 100644
--- a/source3/smbd/vfs.c
+++ b/source3/smbd/vfs.c
@@ -983,7 +983,7 @@ struct smb_filename *vfs_GetWd(TALLOC_CTX *ctx, connection_struct *conn)
 
 /*******************************************************************
  Reduce a file name, removing .. elements and checking that
- it is below dir in the heirachy. This uses realpath.
+ it is below dir in the hierarchy. This uses realpath.
  This function must run as root, and will return names
  and valid stat structs that can be checked on open.
 ********************************************************************/
@@ -1172,7 +1172,7 @@ NTSTATUS check_reduced_name_with_privilege(connection_struct *conn,
 
 /*******************************************************************
  Reduce a file name, removing .. elements and checking that
- it is below dir in the heirachy. This uses realpath.
+ it is below dir in the hierarchy. This uses realpath.
 
  If cwd_name == NULL then fname is a client given path relative
  to the root path of the share.
@@ -2198,7 +2198,7 @@ struct smb_vfs_ev_glue *smb_vfs_ev_glue_create(TALLOC_CTX *mem_ctx,
 	}
 
 	/*
 	 * We now setup the glue hierachie.
 	 *
 	 * Search for "Design of the smb_vfs_ev_glue infrastructure" above
 	 * for a detailed description how the chain works.
@@ -2198,7 +2198,7 @@ struct smb_vfs_ev_glue *smb_vfs_ev_glue_create(TALLOC_CTX *mem_ctx,
 
 	/*
-	 * We now setup the glue hierachie.
+	 * We now setup the glue hierarchy.
 	 *
 	 * Search for "Design of the smb_vfs_ev_glue infrastructure" above
-- 
2.14.4

-------------- next part --------------
A non-text attachment was scrubbed...
Name: signature.asc
Type: application/pgp-signature
Size: 163 bytes
Desc: not available
URL: <http://lists.samba.org/pipermail/samba-technical/attachments/20180911/04899674/signature.sig>


More information about the samba-technical mailing list